pub struct Accounts<T> { /* private fields */ }
Accounts namespace

Implementations

Signs an Ethereum transaction with a given private key.

Transaction signing can perform RPC requests in order to fill missing parameters required for signing nonce, gas_price and chain_id. Note that if all transaction parameters were provided, this future will resolve immediately.

Sign arbitrary string data.

The data is UTF-8 encoded and enveloped the same way as with hash_message. The returned signed data’s signature is in ‘Electrum’ notation, that is the recovery value v is either 27 or 28 (as opposed to the standard notation where v is either 0 or 1). This is important to consider when using this signature with other crates.

Hash a message according to EIP-191.

The data is a UTF-8 encoded string and will enveloped as follows: "\x19Ethereum Signed Message:\n" + message.length + message and hashed using keccak256.