pub struct BaseFilter<T: Transport, I> { /* private fields */ }
Base filter handle. Allows to poll the filter.

Note: because Rust currently doesn’t support async drop, the filter has to be uninstalled manually. See [https://github.com/tomusdrw/rust-web3/issues/583](this tracking issue).

Implementations

Uninstalls the filter

Borrows the transport.

Polls this filter for changes. Will return logs that happened after previous poll.

Returns the stream of items which automatically polls the server

Returns future with all logs matching given filter