Enum pink_web3::types::RecoveryMessage
source · [−]Expand description
Recovery message data.
The message data can either be a binary message that is first hashed according to EIP-191 and then recovered based on the signature or a precomputed hash.
Variants
Data(Vec<u8>)
Message bytes
Hash(H256)
Message hash