pub struct ParityPeerType {
pub active: usize,
pub connected: usize,
pub max: u32,
pub peers: Vec<ParityPeerInfo>,
}Expand description
Stores active peer count, connected count, max connected peers and a list of peers for parity node
Fields
active: usizenumber of active peers
connected: usizenumber of connected peers
max: u32maximum number of peers that can connect
peers: Vec<ParityPeerInfo>list of all peers with details