pub struct TransactionReceipt {
Show 15 fields pub transaction_hash: H256, pub transaction_index: Index, pub block_hash: Option<H256>, pub block_number: Option<U64>, pub from: Address, pub to: Option<Address>, pub cumulative_gas_used: U256, pub gas_used: Option<U256>, pub contract_address: Option<Address>, pub logs: Vec<Log>, pub status: Option<U64>, pub root: Option<H256>, pub logs_bloom: H2048, pub transaction_type: Option<U64>, pub effective_gas_price: Option<U256>,
}
“Receipt” of an executed transaction: details of its execution.

Fields

transaction_hash: H256

Transaction hash.

transaction_index: Index

Index within the block.

block_hash: Option<H256>

Hash of the block this transaction was included within.

block_number: Option<U64>

Number of the block this transaction was included within.

from: Address

Sender Note: default address if the client did not return this value (maintains backwards compatibility for <= 0.7.0 when this field was missing)

to: Option<Address>

Recipient (None when contract creation) Note: Also None if the client did not return this value (maintains backwards compatibility for <= 0.7.0 when this field was missing)

cumulative_gas_used: U256

Cumulative gas used within the block after this was executed.

gas_used: Option<U256>

Gas used by this transaction alone.

Gas used is None if the the client is running in light client mode.

contract_address: Option<Address>

Contract address created, or None if not a deployment.

logs: Vec<Log>

Logs generated within this transaction.

status: Option<U64>

Status: either 1 (success) or 0 (failure).

root: Option<H256>

State root.

logs_bloom: H2048

Logs bloom

transaction_type: Option<U64>

Transaction type, Some(1) for AccessList transaction, None for Legacy

effective_gas_price: Option<U256>

Effective gas price