pub struct ParitySet<T> { /* private fields */ }
Parity_Set Specific API

Implementations

Set Parity to accept non-reserved peers (default behavior)

Add a reserved peer

Set Parity to drop all non-reserved peers. To restore default behavior call parity_acceptNonReservedPeers

Get list of connected/connecting peers.

Attempts to upgrade Parity to the version specified in parity_upgradeReady

Creates a hash of a file at a given URL

Remove a reserved peer

Changes author (coinbase) for mined blocks

Sets the network spec file Parity is using

Sets an authority account for signing consensus messages

Changes extra data for newly mined blocks

Sets new gas ceiling target for mined blocks

Sets a new gas floor target for mined blocks

Sets the maximum amount of gas a single transaction may consume

Changes minimal gas price for transaction to be accepted to the queue

Changes the operating mode of Parity.

Changes limit for transactions in queue. (NOT WORKING !)

Returns a ReleaseInfo object describing the release which is available for upgrade or null if none is available.