pub struct ParitySet<T> { /* private fields */ }Expand description
Parity_Set Specific API
Implementations
sourceimpl<T: Transport> ParitySet<T>
impl<T: Transport> ParitySet<T>
sourcepub fn accept_non_reserved_peers(&self) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn accept_non_reserved_peers(&self) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Set Parity to accept non-reserved peers (default behavior)
sourcepub fn add_reserved_peer(&self, enode: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn add_reserved_peer(&self, enode: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Add a reserved peer
sourcepub fn drop_non_reserved_peers(&self) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn drop_non_reserved_peers(&self) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Set Parity to drop all non-reserved peers. To restore default behavior call parity_acceptNonReservedPeers
sourcepub fn parity_net_peers(&self) -> CallFuture<ParityPeerType, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn parity_net_peers(&self) -> CallFuture<ParityPeerType, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Get list of connected/connecting peers.
sourcepub fn execute_upgrade(&self) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn execute_upgrade(&self) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Attempts to upgrade Parity to the version specified in parity_upgradeReady
sourcepub fn hash_content(&self, url: &str) -> CallFuture<H256, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn hash_content(&self, url: &str) -> CallFuture<H256, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Creates a hash of a file at a given URL
sourcepub fn remove_reserved_peer(&self, enode: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn remove_reserved_peer(&self, enode: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Remove a reserved peer
Changes author (coinbase) for mined blocks
sourcepub fn set_chain(&self, chain: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_chain(&self, chain: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Sets the network spec file Parity is using
sourcepub fn set_engine_signer(
&self,
address: &Address,
password: &str
) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_engine_signer(
&self,
address: &Address,
password: &str
) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Sets an authority account for signing consensus messages
sourcepub fn set_extra_data(&self, data: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_extra_data(&self, data: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Changes extra data for newly mined blocks
sourcepub fn set_gas_ceil_target(&self, quantity: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_gas_ceil_target(&self, quantity: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Sets new gas ceiling target for mined blocks
sourcepub fn set_gas_floor_target(&self, quantity: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_gas_floor_target(&self, quantity: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Sets a new gas floor target for mined blocks
sourcepub fn set_max_transaction_gas(
&self,
quantity: &H256
) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_max_transaction_gas(
&self,
quantity: &H256
) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Sets the maximum amount of gas a single transaction may consume
sourcepub fn set_min_gas_price(&self, quantity: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_min_gas_price(&self, quantity: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Changes minimal gas price for transaction to be accepted to the queue
sourcepub fn set_mode(&self, mode: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_mode(&self, mode: &str) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Changes the operating mode of Parity.
sourcepub fn set_transactions_limit(&self, limit: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn set_transactions_limit(&self, limit: &H256) -> CallFuture<bool, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Changes limit for transactions in queue. (NOT WORKING !)
sourcepub fn upgrade_ready(&self) -> CallFuture<Option<String>, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
pub fn upgrade_ready(&self) -> CallFuture<Option<String>, T::Out>ⓘNotable traits for CallFuture<T, F>impl<T, F> Future for CallFuture<T, F>where
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
T: DeserializeOwned,
F: Future<Output = Result<Vec<u8>>>, type Output = Result<T>;
Returns a ReleaseInfo object describing the release which is available for upgrade or null if none is available.