pub struct Personal<T> { /* private fields */ }
Personal namespace

Implementations

Returns a list of available accounts.

Creates a new account and protects it with given password. Returns the address of created account.

Unlocks the account with given password for some period of time (or single transaction). Returns true if the call was successful.

Sends a transaction from locked account. Returns transaction hash.

Signs an Ethereum specific message with sign(keccak256("\x19Ethereum Signed Message: " + len(data) + data)))

The account does not need to be unlocked to make this call, and will not be left unlocked after. Returns encoded signature.

Signs a transaction without dispatching it to the network. The account does not need to be unlocked to make this call, and will not be left unlocked after. Returns a signed transaction in raw bytes along with it’s details.

Imports a raw key and protects it with the given password. Returns the address of created account.